## 1.0.0 (2025-02-06)


### Internal:

- Make final release, no changes.  [maurits] #610

## 1.0.0a1 (2024-10-31)


### New features:

- Initial release.
  [multiple Plone developers] #1


### Internal:

- Add distribution tests [@ericof] #11
- Add dependencies from Plone package [@ericof] #12

# Changelog

## 1.0a1 (unreleased)

- Initial release.
  []
